# Discord Admin Integration for Rising World
## Complete Manual v3.5.0

![Discord Admin Plugin Logo](https://cdn.discordapp.com/attachments/123456789/123456789/discord_admin_logo.png)

**Author**: Devyn  
**Version**: 3.5.0  
**Last Updated**: April 2025

---

## Table of Contents

1. [Introduction](#introduction)
2. [Installation](#installation)
   - [Requirements](#requirements)
   - [Installation Steps](#installation-steps)
   - [Upgrading from Previous Versions](#upgrading-from-previous-versions)
3. [Configuration](#configuration)
   - [Main Configuration File](#main-configuration-file)
   - [Discord Bot Setup](#discord-bot-setup)
   - [Command Permissions](#command-permissions)
   - [Discord Invite Integration](#discord-invite-integration)
4. [Features](#features)
   - [Server Status Display](#server-status-display)
   - [Player Management](#player-management)
   - [Chat Relay](#chat-relay)
   - [Automated Restarts](#automated-restarts)
   - [Player History System](#player-history-system)
5. [Discord Commands](#discord-commands)
   - [Server Status Commands](#server-status-commands)
   - [Player Management Commands](#player-management-commands)
   - [Server Administration Commands](#server-administration-commands)
   - [Account Management Commands](#account-management-commands)
   - [Discord Management Commands](#discord-management-commands)
   - [Invite Management Commands](#invite-management-commands)
   - [Player History Commands](#player-history-commands)
   - [Restart Schedule Commands](#restart-schedule-commands)
6. [Troubleshooting](#troubleshooting)
   - [Common Issues](#common-issues)
   - [Logs and Debugging](#logs-and-debugging)
   - [Missing Dependencies](#missing-dependencies)
7. [Advanced Features](#advanced-features)
   - [Custom Chat Filter](#custom-chat-filter)
   - [Automatic Backups](#automatic-backups)
   - [Environment Report](#environment-report)
8. [Frequently Asked Questions](#frequently-asked-questions)
9. [Credits and Support](#credits-and-support)

---

## Introduction

The Discord Admin Integration plugin connects your Rising World server to Discord, providing powerful administration tools, player management, chat relay, server status displays, and much more. This integration allows server administrators to manage their Rising World server directly from Discord, while also enhancing the player experience through customizable Discord features.

Key features include:
- Real-time server status display in Discord
- Server management via Discord slash commands
- Bidirectional chat relay between game and Discord
- Player join/leave notifications
- Automatic player tracking and history
- Role-based invite system
- Scheduled server restarts
- And much more!

This manual provides comprehensive documentation for setting up, configuring, and using all features of the Discord Admin plugin.

---

## Installation

### Requirements

Before installing the Discord Admin plugin, ensure your server meets these requirements:

- Rising World dedicated server (Java Edition)
- Java 8 or higher
- Discord account with admin permissions on a Discord server
- Internet connectivity for the server
- Recommended: 2GB+ RAM allocated to the server

### Installation Steps

1. **Download the Plugin**
   - Download the latest version of the plugin from the official source
   - Extract the ZIP file if necessary

2. **Place Files in Plugins Directory**
   - Locate your Rising World server's `Plugins` directory
   - Create a new folder named `Discord Admin Integration` (or similar)
   - Copy all plugin files into this folder

3. **Install Dependencies (Optional)**
   - The plugin will attempt to download dependencies automatically on first run
   - If your server has limited internet access, manually download and place the required JAR files in the `lib` folder within the plugin directory

4. **Create Discord Bot**
   - Follow the Discord Bot setup instructions in the [Discord Bot Setup](#discord-bot-setup) section
   - Configure the bot token and permissions

5. **Start the Server**
   - Start your Rising World server
   - Check the server console for plugin initialization messages
   - Verify the plugin is loaded correctly

6. **Configure the Plugin**
   - Edit `config.properties` to set your Discord bot token and channel ID
   - Restart the server to apply the configuration changes
   - Verify the Discord bot comes online and posts a status message

### Upgrading from Previous Versions

If you're upgrading from a previous version of the Discord Admin plugin, follow these steps:

1. Stop your Rising World server
2. Create a backup of your existing plugin folder
3. Replace all plugin files with the new version
4. Start your server - configuration files will be automatically upgraded

**Note**: The plugin will automatically migrate your settings from v1.0, v2.0, v3.0, v3.1, v3.2, v3.3, or v3.4 to the current format. No manual configuration changes are needed.

---

## Configuration

### Main Configuration File

The main configuration file is located at `plugins/Discord Admin Integration/config.properties`. This file contains all settings for the plugin.

Key configuration sections include:

#### Discord Bot Configuration

```properties
# Discord Bot Configuration
discord.token=YOUR_BOT_TOKEN_HERE
discord.admin.channel=YOUR_CHANNEL_ID_HERE
discord.bot.activity=Watching Rising World
discord.startup.notification=true
discord.error.notification.enabled=true
```

#### Chat Relay Settings

```properties
# Chat Relay Settings
chat.relay.game_to_discord=true
chat.relay.discord_to_game=true
chat.format.discord_to_game=[Discord] %author%: %message%
chat.format.game_to_discord=[Game] %player%: %message%
```

#### Server Status Display Settings

```properties
# Server Status Display Settings
status.updates.enabled=true
status.updates.interval=10
status.embed.online.color=#00FF00
status.embed.offline.color=#FF0000
status.embed.restart.color=#FFA500
status.embed.max_players=15
status.embed.show_admin=false
status.embed.show_player_time=false
```

#### Automatic Restart Configuration

```properties
# Automatic Restart Configuration
restart.daily.enabled=true
restart.daily.time=04:00
restart.timezone=UTC
restart.countdown.minutes=30
restart.warning.times=20,15,10,5,3,1
restart.broadcast.prefix=⚠️ **SERVER RESTART**
restart.pre_shutdown.backup=true
restart.immediate_action=lock
restart.command=YOUR_RESTART_COMMAND
```

#### Discord Message Management

```properties
# Discord Message Management
discord.message.delete.delay=300
discord.message.delete.mode=always
```

#### Player Management

```properties
# Player Management
player.connection.log.enabled=true
player.connection.log.directory=player_connections
player.rejoin.time.track=true
player.history.enabled=true
player.history.max_notes=50
player.welcome.message.enabled=true
player.welcome.message=Welcome to the server, %player%!
```

#### Chat Filter Settings

```properties
# Chat Filter Settings
chat.filter.enabled=false
chat.filter.words=badword1,badword2
```

#### Message Format Settings

```properties
# Message Format Settings
message.join.format=🟢 **%player% joined the server**
message.leave.format=🔴 **%player% left the server**
```

### Discord Bot Setup

To set up your Discord bot:

1. **Create a Discord Application**
   - Go to the [Discord Developer Portal](https://discord.com/developers/applications)
   - Click "New Application" and give it a name
   - Navigate to the "Bot" tab and click "Add Bot"
   - Under the "Privileged Gateway Intents" section, enable:
     - Server Members Intent
     - Message Content Intent
     - Guild Presences Intent

2. **Set Bot Permissions**
   - In the OAuth2 URL Generator (OAuth2 tab), select:
     - `bot` and `applications.commands` scopes
     - Required permissions:
       - Manage Channels
       - Manage Roles
       - Manage Webhooks
       - Send Messages
       - Embed Links
       - Attach Files
       - Read Message History
       - Mention Everyone
       - Add Reactions
       - View Channels
       - Use Slash Commands
       - Manage Messages
       - Read Message History

3. **Get Bot Token**
   - In the Bot tab, click "Reset Token" or copy the existing token
   - Add this token to your `config.properties` file: `discord.token=YOUR_TOKEN_HERE`

4. **Invite Bot to Your Server**
   - Use the generated OAuth2 URL to invite the bot to your Discord server
   - Ensure the bot has access to your designated admin channel

5. **Set Channel ID**
   - Enable Developer Mode in Discord (User Settings > Advanced)
   - Right-click on your admin channel and select "Copy ID"
   - Add this ID to your `config.properties` file: `discord.admin.channel=YOUR_CHANNEL_ID_HERE`

### Command Permissions

The plugin uses a permission system to control which Discord users can access certain commands. These permissions are configured in the `command_permissions.properties` file.

Example configuration:

```properties
# Enable the command
kick.enabled=true

# Discord permissions required to use the command
kick.roles=ADMINISTRATOR,KICK_MEMBERS

# Public command accessible to everyone
players.enabled=true
players.roles=
```

Available permissions match Discord's permission system:
- `ADMINISTRATOR` - Full server control
- `MANAGE_SERVER` - Manage server settings
- `MANAGE_CHANNELS` - Create/edit/delete channels
- `MANAGE_ROLES` - Create/edit/delete roles
- `KICK_MEMBERS` - Kick members from server
- `BAN_MEMBERS` - Ban members from server
- `MODERATE_MEMBERS` - Timeout members
- `VIEW_AUDIT_LOG` - See server audit logs
- `CREATE_INSTANT_INVITE` - Create invites
- `MESSAGE_MENTION_EVERYONE` - Mention @everyone

Use `EVERYONE` or leave the roles field empty to allow all users to access a command.

### Discord Invite Integration

The plugin can automatically create and manage Discord invites that assign specific roles:

```properties
# Automatically assign roles based on invite used
invite.auto_assign_role=true

# Tracking window (in seconds) for invite usage detection
invite.tracking_window=15

# Discord welcome message for new members
invite.welcome_message=Welcome, %user%! Join our game server with /link
```

To create role-assigning invites, use the `/create_invite` command in Discord. These invites will automatically assign the specified role when used.

---

## Features

### Server Status Display

The plugin creates and maintains a real-time server status display in your configured Discord channel. This display shows:

- Current server status (online/offline/restarting)
- Number of online players and max player count
- List of currently online players
- Server uptime
- Last update timestamp

The status message is pinned to the channel and automatically updates at the interval specified in `status.updates.interval` (default: 10 minutes).

**Customization options:**
- Change colors for different server states
- Set maximum number of players to list
- Configure automatic update interval
- Show/hide admin status and player connection time

### Player Management

The plugin provides comprehensive player management capabilities:

- Track player connections and disconnections
- Log player session durations
- Link Discord accounts to game accounts
- Manage admin promotions and demotions
- Send automatic Discord invites to new players
- Record player warnings and notes

Player information is stored persistently across server restarts.

### Chat Relay

The bidirectional chat relay feature allows messages to flow between your Discord server and the Rising World game chat:

- Game chat messages appear in Discord
- Discord messages appear in the game
- Configurable message formats
- Optional chat filtering
- Support for emoji and basic formatting

Configure the appearance using these settings:
```properties
chat.format.discord_to_game=[Discord] %author%: %message%
chat.format.game_to_discord=[Game] %player%: %message%
```

### Automated Restarts

Schedule automatic server restarts with countdown notifications:

- Daily restart at specified time
- Configurable timezone support
- Multiple warning notifications at customizable intervals
- Pre-restart server backup
- Customizable restart message prefix
- Options to lock server or kick players before restart

Configure using:
```properties
restart.daily.enabled=true
restart.daily.time=04:00
restart.timezone=UTC
restart.countdown.minutes=30
restart.warning.times=20,15,10,5,3,1
```

### Player History System

The plugin includes a comprehensive player history system that lets administrators:

- Add warnings to players
- Record staff notes about players
- View detailed player history reports
- Track player behavior across multiple sessions

This history is persistent and available through Discord commands.

---

## Discord Commands

The plugin adds many slash commands to Discord for server management. All commands use Discord's slash command system for easy discovery and usage.

### Server Status Commands

- `/players` - List all online players
  - Available to everyone by default
  - Shows current online players on the server

- `/refresh_status` - Refresh the server status message
  - Requires ADMINISTRATOR or MANAGE_SERVER permissions
  - Useful if the status message needs manual updating

### Player Management Commands

- `/kick <player> [reason]` - Kick a player from the server
  - Requires KICK_MEMBERS or ADMINISTRATOR permissions
  - Optional reason parameter will be shown to the kicked player

- `/ban <player> [reason] [time]` - Ban a player from the server
  - Requires BAN_MEMBERS or ADMINISTRATOR permissions
  - Optional reason parameter
  - Optional time parameter (in minutes, -1 for permanent)
  - Time choices: 1 minute, 5 minutes, 15 minutes, 30 minutes, 1 hour, 6 hours, 12 hours, 1 day, 1 week, Permanent

- `/unban <player>` - Unban a player from the server
  - Requires BAN_MEMBERS or ADMINISTRATOR permissions
  - The player must have connected at least once while the plugin was active

- `/teleport <player> [x] [y] [z] [target]` - Teleport a player
  - Requires ADMINISTRATOR permissions
  - Either specify coordinates or a target player to teleport to

### Server Administration Commands

- `/broadcast <message>` - Broadcast a message to all players
  - Requires MANAGE_SERVER or ADMINISTRATOR permissions
  - Message is sent to all connected players

- `/restart` - Schedule server restart
  - Requires MANAGE_SERVER or ADMINISTRATOR permissions
  - Initiates the restart sequence with configured countdown

- `/reload_config` - Reload plugin configuration files
  - Requires ADMINISTRATOR permissions
  - Reloads the Rising World plugins

### Account Management Commands

- `/link <username>` - Link your Discord account to your game account
  - Available to everyone by default
  - Links the Discord user to their in-game name
  - Required for some permission checks

- `/promote <player>` - Promote a player to admin
  - Requires ADMINISTRATOR permissions
  - Makes the specified player an admin in-game

- `/demote <player>` - Demote a player from admin
  - Requires ADMINISTRATOR permissions
  - Removes admin status from the specified player

### Discord Management Commands

- `/reset_discord_connection <player>` - Reset Discord connection status for a player
  - Requires ADMINISTRATOR permissions
  - Makes the player receive a Discord invite on next connection

- `/send_discord_invite <player> [invite_code]` - Send Discord invite to a player
  - Requires ADMINISTRATOR permissions
  - Sends an invite to the specified player
  - Optional specific invite code parameter

### Invite Management Commands

- `/create_invite <channel> <role> [max_uses] [expiration_hours]` - Create an invite that assigns a role
  - Requires CREATE_INSTANT_INVITE or ADMINISTRATOR permissions
  - Channel ID parameter for where to create the invite
  - Role ID parameter for role to assign
  - Optional maximum uses parameter (0 for unlimited)
  - Optional expiration time in hours (0 for never)

- `/link_invite <channel> <code> <role>` - Link existing invite with a role
  - Requires MANAGE_CHANNEL or ADMINISTRATOR permissions
  - Associates an existing invite with automatic role assignment

- `/delete_invite <code>` - Delete a role invite
  - Requires MANAGE_CHANNEL or ADMINISTRATOR permissions
  - Removes the specified invite

- `/list_invites` - List all role invites
  - Requires MANAGE_CHANNEL or ADMINISTRATOR permissions
  - Shows all managed invites and their associated roles

- `/set_default_invite <invite_code>` - Set default invite for automatic player invites
  - Requires ADMINISTRATOR permissions
  - Sets which invite is sent to new players automatically

### Player History Commands

- `/warn <player> <reason>` - Add a warning to a player
  - Requires KICK_MEMBERS or ADMINISTRATOR permissions
  - Permanently records a warning in the player's history
  - If the player is online, they will receive the warning message

- `/note <player> <note>` - Add a note to a player's history
  - Requires KICK_MEMBERS or ADMINISTRATOR permissions
  - Records a staff note about the player

- `/history <player>` - View a player's history
  - Requires KICK_MEMBERS or ADMINISTRATOR permissions
  - Shows warnings, notes, and other information about the player

- `/delete_note <player> <note_id>` - Delete a note from a player's history
  - Requires ADMINISTRATOR permissions
  - Removes a specific note by its ID

### Restart Schedule Commands

- `/restart_enable <enabled>` - Enable or disable automatic server restarts
  - Requires ADMINISTRATOR permissions
  - Boolean parameter to enable or disable

- `/restart_time <time>` - Set the daily restart time
  - Requires ADMINISTRATOR permissions
  - Time parameter in HH:MM format (24-hour)

- `/restart_timezone <timezone>` - Set the timezone for restarts
  - Requires ADMINISTRATOR permissions
  - Timezone ID parameter (e.g., UTC, America/New_York)

- `/list_timezones [common_only]` - List available timezones
  - Requires ADMINISTRATOR permissions
  - Optional boolean parameter to show only common timezones

---

## Troubleshooting

### Common Issues

**Bot doesn't come online:**
- Check your bot token in `config.properties`
- Ensure your bot has been added to your Discord server
- Verify internet connectivity from your server
- Check server logs for any error messages

**Missing slash commands:**
- Make sure the bot has the `applications.commands` scope when invited
- Allow up to 1 hour for slash commands to register globally
- Try re-inviting the bot with the correct permissions

**Cannot execute commands:**
- Check command permissions in `command_permissions.properties`
- Verify your Discord roles have the required permissions
- Make sure your Discord account is linked if needed (`/link` command)

**Status message not updating:**
- Check if the `status.updates.enabled` setting is true
- Verify the correct channel ID in `discord.admin.channel`
- Try manually refreshing with `/refresh_status` command

**Discord invite system not working:**
- Check if invites are created correctly with `/create_invite`
- Verify the bot has `CREATE_INSTANT_INVITE` and `MANAGE_ROLES` permissions
- Set a default invite with `/set_default_invite`

### Logs and Debugging

The plugin maintains detailed logs in the `plugins/Discord Admin Integration/logs` directory.

To enable debug logging, set this in `config.properties`:
```properties
logs.level=DEBUG
logs.console.debug=true
```

When troubleshooting issues, useful log files include:
- `discord_admin_YYYY-MM-DD.log` - Main plugin log
- `environment_report.txt` - Dependency and environment information
- `player_connections/connections_YYYY-MM-DD.log` - Player connection logs

### Missing Dependencies

The plugin requires several Java libraries to function properly. On first startup, it will attempt to download these automatically, but if your server has no internet access, you'll need to install them manually.

Required dependencies:
- JDA (Java Discord API)
- JSON-Simple
- SLF4J API and Simple
- OkHttp
- Trove4J
- Jackson Core, Annotations, and Databind

If dependencies are missing, check the `environment_report.txt` file for download URLs, and place the JAR files in the `plugins/Discord Admin Integration/lib` directory.

---

## Advanced Features

### Custom Chat Filter

The plugin includes a configurable chat filter that can block or censor specific words from being relayed:

```properties
# Enable the chat filter
chat.filter.enabled=true

# Comma-separated list of words to filter
chat.filter.words=badword1,badword2,badword3
```

The filter is applied to both in-game messages sent to Discord and Discord messages sent to the game. Filtered words are replaced with asterisks (***).

The filter is smart enough to detect simple letter substitutions and spacing tricks.

### Automatic Backups

The plugin can create automatic backups before server restarts:

```properties
# Create backup before restart
restart.pre_shutdown.backup=true

# Directory for backups
backup.directory=backups

# Maximum number of backups to keep
backup.max_count=10
```

Backups include:
- World data
- Plugin configurations
- Server settings
- Permission files

Old backups are automatically cleaned up to save disk space.

### Environment Report

The plugin creates a detailed environment report on startup, which can be useful for troubleshooting:
- Java version and environment details
- Dependencies status
- Network connectivity
- Library versions
- Classpath information

This report is saved as `environment_report.txt` in the plugin directory.

---

## Frequently Asked Questions

**Q: Can I use this plugin with multiple Discord servers?**  
A: No, the plugin is designed to connect to a single Discord server at a time.

**Q: Does this plugin work with Rising World Legacy Edition?**  
A: No, this plugin is specifically designed for the Java Edition of Rising World.

**Q: Can players see commands executed through Discord?**  
A: Yes, by default command usage is logged in both Discord and the game console. 

**Q: Is there a way to get direct messages from players to Discord?**  
A: No, only global chat messages are relayed to Discord in the current version.

**Q: Can I customize which Discord roles can use each command?**  
A: Yes, you can configure command permissions in the `command_permissions.properties` file.

**Q: How do I change the format of join/leave messages?**  
A: Edit the `message.join.format` and `message.leave.format` settings in `config.properties`.

**Q: Does the plugin support multiple languages?**  
A: The plugin itself is in English, but all messages are configurable to support other languages.

**Q: Why am I getting "Missing Dependencies" errors?**  
A: Your server might not have internet access to download required libraries. Install them manually by following the instructions in the [Missing Dependencies](#missing-dependencies) section.

**Q: Can I use this plugin alongside other Discord bots?**  
A: Yes, the plugin is designed to work alongside other Discord bots without conflicts.

---

*This manual was last updated in April 2025 for Discord Admin Integration v3.5.0.*
